# I2C-GUI++
A new and improved I2C communication library with a GUI

This is currently a placeholder for the I2C-GUI++ project.

You can install the I2C-GUI++ libraries and GUI with: `python -m pip install I2C-GUI2`

After installation, you can run the individual chip GUIs with dedicated commands such as: `etroc2_gui`
